BotMetadata class

Provides information about a bot. .

Constructors

BotMetadata({DateTime? createdDate, String? description, DateTime? lastUpdatedDate, String? name, Status? status, String? version})
BotMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

createdDate → DateTime?
The date that the bot was created.
final
description → String?
A description of the bot.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedDate → DateTime?
The date that the bot was updated. When you create a bot, the creation date and last updated date are the same.
final
name → String?
The name of the bot.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Status?
The status of the bot.
final
version → String?
The version of the bot. For a new bot, the version is always $LATEST.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited