CreateBotVersionResponse class

Constructors

CreateBotVersionResponse({Statement? abortStatement, String? checksum, bool? childDirected, Prompt? clarificationPrompt, DateTime? createdDate, String? description, bool? detectSentiment, bool? enableModelImprovements, String? failureReason, int? idleSessionTTLInSeconds, List<Intent>? intents, DateTime? lastUpdatedDate, Locale? locale, String? name, Status? status, String? version, String? voiceId})
CreateBotVersionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

abortStatement → Statement?
The message that Amazon Lex uses to cancel a conversation. For more information, see PutBot.
final
checksum → String?
Checksum identifying the version of the bot that was created.
final
childDirected → bool?
For each Amazon Lex bot created with the Amazon Lex Model Building Service, you must specify whether your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to the Children's Online Privacy Protection Act (COPPA) by specifying true or false in the childDirected field. By specifying true in the childDirected field, you confirm that your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA. By specifying false in the childDirected field, you confirm that your use of Amazon Lex is not related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA. You may not specify a default value for the childDirected field that does not accurately reflect whether your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA.
final
clarificationPrompt → Prompt?
The message that Amazon Lex uses when it doesn't understand the user's request. For more information, see PutBot.
final
createdDate → DateTime?
The date when the bot version was created.
final
description → String?
A description of the bot.
final
detectSentiment → bool?
Indicates whether utterances entered by the user should be sent to Amazon Comprehend for sentiment analysis.
final
enableModelImprovements → bool?
Indicates whether the bot uses accuracy improvements. true indicates that the bot is using the improvements, otherwise, false.
final
failureReason → String?
If status is FAILED, Amazon Lex provides the reason that it failed to build the bot.
final
hashCode → int
The hash code for this object.
no setterinherited
idleSessionTTLInSeconds → int?
The maximum time in seconds that Amazon Lex retains the data gathered in a conversation. For more information, see PutBot.
final
intents → List<Intent>?
An array of Intent objects. For more information, see PutBot.
final
lastUpdatedDate → DateTime?
The date when the $LATEST version of this bot was updated.
final
locale → Locale?
Specifies the target locale for the bot.
final
name → String?
The name of the bot.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Status?
When you send a request to create or update a bot, Amazon Lex sets the status response element to BUILDING. After Amazon Lex builds the bot, it sets status to READY. If Amazon Lex can't build the bot, it sets status to FAILED. Amazon Lex returns the reason for the failure in the failureReason response element.
final
version → String?
The version of the bot.
final
voiceId → String?
The Amazon Polly voice ID that Amazon Lex uses for voice interactions with the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited