CreateIntentVersionResponse class

Constructors

CreateIntentVersionResponse({String? checksum, Statement? conclusionStatement, Prompt? confirmationPrompt, DateTime? createdDate, String? description, CodeHook? dialogCodeHook, FollowUpPrompt? followUpPrompt, FulfillmentActivity? fulfillmentActivity, List<InputContext>? inputContexts, KendraConfiguration? kendraConfiguration, DateTime? lastUpdatedDate, String? name, List<OutputContext>? outputContexts, String? parentIntentSignature, Statement? rejectionStatement, List<String>? sampleUtterances, List<Slot>? slots, String? version})
CreateIntentVersionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

checksum → String?
Checksum of the intent version created.
final
conclusionStatement → Statement?
After the Lambda function specified in the fulfillmentActivity field fulfills the intent, Amazon Lex conveys this statement to the user.
final
confirmationPrompt → Prompt?
If defined, the prompt that Amazon Lex uses to confirm the user's intent before fulfilling it.
final
createdDate → DateTime?
The date that the intent was created.
final
description → String?
A description of the intent.
final
dialogCodeHook → CodeHook?
If defined, Amazon Lex invokes this Lambda function for each user input.
final
followUpPrompt → FollowUpPrompt?
If defined, Amazon Lex uses this prompt to solicit additional user activity after the intent is fulfilled.
final
fulfillmentActivity → FulfillmentActivity?
Describes how the intent is fulfilled.
final
hashCode → int
The hash code for this object.
no setterinherited
inputContexts → List<InputContext>?
An array of InputContext objects that lists the contexts that must be active for Amazon Lex to choose the intent in a conversation with the user.
final
kendraConfiguration → KendraConfiguration?
Configuration information, if any, for connecting an Amazon Kendra index with the AMAZON.KendraSearchIntent intent.
final
lastUpdatedDate → DateTime?
The date that the intent was updated.
final
name → String?
The name of the intent.
final
outputContexts → List<OutputContext>?
An array of OutputContext objects that lists the contexts that the intent activates when the intent is fulfilled.
final
parentIntentSignature → String?
A unique identifier for a built-in intent.
final
rejectionStatement → Statement?
If the user answers "no" to the question defined in confirmationPrompt, Amazon Lex responds with this statement to acknowledge that the intent was canceled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleUtterances → List<String>?
An array of sample utterances configured for the intent.
final
slots → List<Slot>?
An array of slot types that defines the information required to fulfill the intent.
final
version → String?
The version number assigned to the new version of the intent.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited