CreateSlotTypeVersionResponse class

Constructors

CreateSlotTypeVersionResponse({String? checksum, DateTime? createdDate, String? description, List<EnumerationValue>? enumerationValues, DateTime? lastUpdatedDate, String? name, String? parentSlotTypeSignature, List<SlotTypeConfiguration>? slotTypeConfigurations, SlotValueSelectionStrategy? valueSelectionStrategy, String? version})
CreateSlotTypeVersionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

checksum → String?
Checksum of the $LATEST version of the slot type.
final
createdDate → DateTime?
The date that the slot type was created.
final
description → String?
A description of the slot type.
final
enumerationValues → List<EnumerationValue>?
A list of EnumerationValue objects that defines the values that the slot type can take.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedDate → DateTime?
The date that the slot type was updated. When you create a resource, the creation date and last update date are the same.
final
name → String?
The name of the slot type.
final
parentSlotTypeSignature → String?
The built-in slot type used a the parent of the slot type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slotTypeConfigurations → List<SlotTypeConfiguration>?
Configuration information that extends the parent built-in slot type.
final
valueSelectionStrategy → SlotValueSelectionStrategy?
The strategy that Amazon Lex uses to determine the value of the slot. For more information, see PutSlotType.
final
version → String?
The version assigned to the new slot type version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited