GetBotAliasResponse class

Constructors

GetBotAliasResponse({String? botName, String? botVersion, String? checksum, ConversationLogsResponse? conversationLogs, DateTime? createdDate, String? description, DateTime? lastUpdatedDate, String? name})
GetBotAliasResponse.fromJson(Map<String, dynamic> json)
factory

Properties

botName → String?
The name of the bot that the alias points to.
final
botVersion → String?
The version of the bot that the alias points to.
final
checksum → String?
Checksum of the bot alias.
final
conversationLogs → ConversationLogsResponse?
The settings that determine how Amazon Lex uses conversation logs for the alias.
final
createdDate → DateTime?
The date that the bot alias was created.
final
description → String?
A description of the bot alias.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedDate → DateTime?
The date that the bot alias was updated. When you create a resource, the creation date and the last updated date are the same.
final
name → String?
The name of the bot alias.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited