GetBotChannelAssociationResponse class

Constructors

GetBotChannelAssociationResponse({String? botAlias, Map<String, String>? botConfiguration, String? botName, DateTime? createdDate, String? description, String? failureReason, String? name, ChannelStatus? status, ChannelType? type})
GetBotChannelAssociationResponse.fromJson(Map<String, dynamic> json)
factory

Properties

botAlias → String?
An alias pointing to the specific version of the Amazon Lex bot to which this association is being made.
final
botConfiguration → Map<String, String>?
Provides information that the messaging platform needs to communicate with the Amazon Lex bot.
final
botName → String?
The name of the Amazon Lex bot.
final
createdDate → DateTime?
The date that the association between the bot and the channel was created.
final
description → String?
A description of the association between the bot and the channel.
final
failureReason → String?
If status is FAILED, Amazon Lex provides the reason that it failed to create the association.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the association between the bot and the channel.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ChannelStatus?
The status of the bot channel.
final
type → ChannelType?
The type of the messaging platform.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited