GetBotChannelAssociationsResponse class

Constructors

GetBotChannelAssociationsResponse({List<BotChannelAssociation>? botChannelAssociations, String? nextToken})
GetBotChannelAssociationsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

botChannelAssociations → List<BotChannelAssociation>?
An array of objects, one for each association, that provides information about the Amazon Lex bot and its association with the channel.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
A pagination token that fetches the next page of associations. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of associations, specify the pagination token in the next request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited