GetBotResponse class

Constructors

GetBotResponse({Statement? abortStatement, String? checksum, bool? childDirected, Prompt? clarificationPrompt, DateTime? createdDate, String? description, bool? detectSentiment, bool? enableModelImprovements, String? failureReason, int? idleSessionTTLInSeconds, List<Intent>? intents, DateTime? lastUpdatedDate, Locale? locale, String? name, double? nluIntentConfidenceThreshold, Status? status, String? version, String? voiceId})
GetBotResponse.fromJson(Map<String, dynamic> json)
factory

Properties

abortStatement → Statement?
The message that Amazon Lex returns when the user elects to end the conversation without completing it. For more information, see PutBot.
final
checksum → String?
Checksum of the bot used to identify a specific revision of the bot's $LATEST version.
final
childDirected → bool?
For each Amazon Lex bot created with the Amazon Lex Model Building Service, you must specify whether your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to the Children's Online Privacy Protection Act (COPPA) by specifying true or false in the childDirected field. By specifying true in the childDirected field, you confirm that your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA. By specifying false in the childDirected field, you confirm that your use of Amazon Lex is not related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA. You may not specify a default value for the childDirected field that does not accurately reflect whether your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA.
final
clarificationPrompt → Prompt?
The message Amazon Lex uses when it doesn't understand the user's request. For more information, see PutBot.
final
createdDate → DateTime?
The date that the bot was created.
final
description → String?
A description of the bot.
final
detectSentiment → bool?
Indicates whether user utterances should be sent to Amazon Comprehend for sentiment analysis.
final
enableModelImprovements → bool?
Indicates whether the bot uses accuracy improvements. true indicates that the bot is using the improvements, otherwise, false.
final
failureReason → String?
If status is FAILED, Amazon Lex explains why it failed to build the bot.
final
hashCode → int
The hash code for this object.
no setterinherited
idleSessionTTLInSeconds → int?
The maximum time in seconds that Amazon Lex retains the data gathered in a conversation. For more information, see PutBot.
final
intents → List<Intent>?
An array of intent objects. For more information, see PutBot.
final
lastUpdatedDate → DateTime?
The date that the bot was updated. When you create a resource, the creation date and last updated date are the same.
final
locale → Locale?
The target locale for the bot.
final
name → String?
The name of the bot.
final
nluIntentConfidenceThreshold → double?
The score that determines where Amazon Lex inserts the AMAZON.FallbackIntent, AMAZON.KendraSearchIntent, or both when returning alternative intents in a PostContent or PostText response. AMAZON.FallbackIntent is inserted if the confidence score for all intents is below this value. AMAZON.KendraSearchIntent is only inserted if it is configured for the bot.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Status?
The status of the bot.
final
version → String?
The version of the bot. For a new bot, the version is always $LATEST.
final
voiceId → String?
The Amazon Polly voice ID that Amazon Lex uses for voice interaction with the user. For more information, see PutBot.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited