GetBuiltinSlotTypesResponse class

Constructors

GetBuiltinSlotTypesResponse({String? nextToken, List<BuiltinSlotTypeMetadata>? slotTypes})
GetBuiltinSlotTypesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If the response is truncated, the response includes a pagination token that you can use in your next request to fetch the next page of slot types.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slotTypes → List<BuiltinSlotTypeMetadata>?
An array of BuiltInSlotTypeMetadata objects, one entry for each slot type returned.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited