GetExportResponse class

Constructors

GetExportResponse({ExportStatus? exportStatus, ExportType? exportType, String? failureReason, String? name, ResourceType? resourceType, String? url, String? version})
GetExportResponse.fromJson(Map<String, dynamic> json)
factory

Properties

exportStatus → ExportStatus?
The status of the export.
final
exportType → ExportType?
The format of the exported data.
final
failureReason → String?
If status is FAILED, Amazon Lex provides the reason that it failed to export the resource.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the bot being exported.
final
resourceType → ResourceType?
The type of the exported resource.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
An S3 pre-signed URL that provides the location of the exported resource. The exported resource is a ZIP archive that contains the exported resource in JSON format. The structure of the archive may change. Your code should not rely on the archive structure.
final
version → String?
The version of the bot being exported.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited