GetImportResponse class

Constructors

GetImportResponse({DateTime? createdDate, List<String>? failureReason, String? importId, ImportStatus? importStatus, MergeStrategy? mergeStrategy, String? name, ResourceType? resourceType})
GetImportResponse.fromJson(Map<String, dynamic> json)
factory

Properties

createdDate → DateTime?
A timestamp for the date and time that the import job was created.
final
failureReason → List<String>?
A string that describes why an import job failed to complete.
final
hashCode → int
The hash code for this object.
no setterinherited
importId → String?
The identifier for the specific import job.
final
importStatus → ImportStatus?
The status of the import job. If the status is FAILED, you can get the reason for the failure from the failureReason field.
final
mergeStrategy → MergeStrategy?
The action taken when there was a conflict between an existing resource and a resource in the import file.
final
name → String?
The name given to the import job.
final
resourceType → ResourceType?
The type of resource imported.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited