GetIntentsResponse class

Constructors

GetIntentsResponse({List<IntentMetadata>? intents, String? nextToken})
GetIntentsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
intents → List<IntentMetadata>?
An array of Intent objects. For more information, see PutBot.
final
nextToken → String?
If the response is truncated, the response includes a pagination token that you can specify in your next request to fetch the next page of intents.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited