Message class

The message object that provides the message text and its type.

Constructors

Message({required String content, required ContentType contentType, int? groupNumber})
Message.fromJson(Map<String, dynamic> json)
factory

Properties

content → String
The text of the message.
final
contentType → ContentType
The content type of the message string.
final
groupNumber → int?
Identifies the message group that the message belongs to. When a group is assigned to a message, Amazon Lex returns one message from each group in the response.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited