PutIntentResponse class

Constructors

PutIntentResponse({String? checksum, Statement? conclusionStatement, Prompt? confirmationPrompt, bool? createVersion, DateTime? createdDate, String? description, CodeHook? dialogCodeHook, FollowUpPrompt? followUpPrompt, FulfillmentActivity? fulfillmentActivity, List<InputContext>? inputContexts, KendraConfiguration? kendraConfiguration, DateTime? lastUpdatedDate, String? name, List<OutputContext>? outputContexts, String? parentIntentSignature, Statement? rejectionStatement, List<String>? sampleUtterances, List<Slot>? slots, String? version})
PutIntentResponse.fromJson(Map<String, dynamic> json)
factory

Properties

checksum → String?
Checksum of the $LATESTversion of the intent created or updated.
final
conclusionStatement → Statement?
After the Lambda function specified in thefulfillmentActivityintent fulfills the intent, Amazon Lex conveys this statement to the user.
final
confirmationPrompt → Prompt?
If defined in the intent, Amazon Lex prompts the user to confirm the intent before fulfilling it.
final
createdDate → DateTime?
The date that the intent was created.
final
createVersion → bool?
True if a new version of the intent was created. If the createVersion field was not specified in the request, the createVersion field is set to false in the response.
final
description → String?
A description of the intent.
final
dialogCodeHook → CodeHook?
If defined in the intent, Amazon Lex invokes this Lambda function for each user input.
final
followUpPrompt → FollowUpPrompt?
If defined in the intent, Amazon Lex uses this prompt to solicit additional user activity after the intent is fulfilled.
final
fulfillmentActivity → FulfillmentActivity?
If defined in the intent, Amazon Lex invokes this Lambda function to fulfill the intent after the user provides all of the information required by the intent.
final
hashCode → int
The hash code for this object.
no setterinherited
inputContexts → List<InputContext>?
An array of InputContext objects that lists the contexts that must be active for Amazon Lex to choose the intent in a conversation with the user.
final
kendraConfiguration → KendraConfiguration?
Configuration information, if any, required to connect to an Amazon Kendra index and use the AMAZON.KendraSearchIntent intent.
final
lastUpdatedDate → DateTime?
The date that the intent was updated. When you create a resource, the creation date and last update dates are the same.
final
name → String?
The name of the intent.
final
outputContexts → List<OutputContext>?
An array of OutputContext objects that lists the contexts that the intent activates when the intent is fulfilled.
final
parentIntentSignature → String?
A unique identifier for the built-in intent that this intent is based on.
final
rejectionStatement → Statement?
If the user answers "no" to the question defined in confirmationPrompt Amazon Lex responds with this statement to acknowledge that the intent was canceled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleUtterances → List<String>?
An array of sample utterances that are configured for the intent.
final
slots → List<Slot>?
An array of intent slots that are configured for the intent.
final
version → String?
The version of the intent. For a new intent, the version is always $LATEST.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited